@@ -1,10 +1,6 @@
-from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class CatalogSource(NamespacedResource):
     api_group = NamespacedResource.ApiGroup.OPERATORS_COREOS_COM
 
