@@ -1,15 +1,11 @@
 # -*- coding: utf-8 -*-
 
 
-from ocp_resources.logger import get_logger
 from ocp_resources.persistent_volume_claim import PersistentVolumeClaim
 from ocp_resources.resource import TIMEOUT, NamespacedResource, Resource
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class DataVolume(NamespacedResource):
     """
     DataVolume object.
@@ -225,5 +221,5 @@ class DataVolume(NamespacedResource):
                 else:
                     break
         except TimeoutExpiredError:
-            LOGGER.error(f"{self.name} status is {sample}")
+            self.logger.error(f"{self.name} status is {sample}")
             raise
