@@ -1,10 +1,6 @@
-from ocp_resources.logger import get_logger
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-LOGGER = get_logger(name=__name__)
-
-
 def _get_status_condition_log_message(**status_condition):
     log_msg = "Waiting For: \n"
     for status_condition_name, status_condition in status_condition.items():
@@ -76,7 +72,7 @@ class MTV:
         Wait for MTV Resource Status Conditions.
         """
 
-        LOGGER.info(
+        self.logger.info(
             _get_status_condition_log_message(
                 condition_status=condition_status,
                 condition_type=condition_type,
@@ -124,7 +120,7 @@ class MTV:
                         return
 
         except TimeoutExpiredError:
-            LOGGER.error(
+            self.logger.error(
                 msg=f"Last Status Condition of {self.kind} {self.name} was: {last_condition}"
             )
             raise
