@@ -28,8 +28,8 @@ class NetworkMap(NamespacedResource, MTV):
 
     def __init__(
         self,
-        name,
-        namespace,
+        name=None,
+        namespace=None,
         mapping=None,
         source_provider_name=None,
         source_provider_namespace=None,
@@ -37,9 +37,14 @@ class NetworkMap(NamespacedResource, MTV):
         destination_provider_namespace=None,
         client=None,
         teardown=True,
+        yaml_file=None,
     ):
         super().__init__(
-            name=name, namespace=namespace, client=client, teardown=teardown
+            name=name,
+            namespace=namespace,
+            client=client,
+            teardown=teardown,
+            yaml_file=yaml_file,
         )
         self.mapping = mapping
         self.source_provider_name = source_provider_name
@@ -50,5 +55,8 @@ class NetworkMap(NamespacedResource, MTV):
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         res.update(self.map_to_dict)
         return res
