@@ -2,13 +2,10 @@ import time
 
 from openshift.dynamic.exceptions import ConflictError
 
-from ocp_resources.logger import get_logger
 from ocp_resources.resource import Resource
 from ocp_resources.utils import TimeoutSampler
 
 
-LOGGER = get_logger(name=__name__)
-
 SLEEP = 1
 TIMEOUT = 240
 
@@ -74,7 +71,7 @@ class NodeNetworkState(Resource):
 
             return None
 
-        LOGGER.info(f"Checking if interface {name} is up -- {self.name}")
+        self.logger.info(f"Checking if interface {name} is up -- {self.name}")
         samples = TimeoutSampler(
             wait_timeout=TIMEOUT, sleep=SLEEP, func=_find_up_interface
         )
@@ -83,7 +80,7 @@ class NodeNetworkState(Resource):
                 return
 
     def wait_until_deleted(self, name):
-        LOGGER.info(f"Checking if interface {name} is deleted -- {self.name}")
+        self.logger.info(f"Checking if interface {name} is deleted -- {self.name}")
         samples = TimeoutSampler(
             wait_timeout=TIMEOUT, sleep=SLEEP, func=self.get_interface, name=name
         )
