@@ -1,12 +1,8 @@
 # -*- coding: utf-8 -*-
 
-from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class Route(NamespacedResource):
     """
     OpenShift Route object.
