@@ -2,15 +2,11 @@
 
 
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT
-from ocp_resources.logger import get_logger
 from ocp_resources.resource import TIMEOUT, NamespacedResource
 from ocp_resources.utils import TimeoutSampler
 from ocp_resources.virtual_machine import VirtualMachine
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class VirtualMachineSnapshot(NamespacedResource):
     """
     VirtualMachineSnapshot object.
@@ -60,7 +56,7 @@ class VirtualMachineSnapshot(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        LOGGER.info(
+        self.logger.info(
             f"Wait for {self.kind} {self.name} status to be {'' if status else 'not '}ready to use"
         )
 
